<?php

namespace App\Http\Controllers\Orion;

use App\Http\Controllers\Controller;
use App\Http\Requests\Orion\FilteredSearchRequest;
use App\Http\Requests\Orion\GetLinkRequest;
use App\Http\Requests\Orion\ManualSearchRequest;
use App\Http\Services\OrionService;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class SearchController extends Controller
{
    public function index() {
        return view('search');
    }
    
    public function searchWithoutToken(ManualSearchRequest $request): JsonResponse
    {
        $orion = new OrionService();
        $orion->compileTypes($request);
        $response = $orion->specificSearch($request->input('search'));

        if ($response->status === "success") {
            return response()->json([
                'html' => view('components.search-result-card', [
                    "results" => collect($response->data)
                ])->render(),
                'result' => $response->result,
                'status' => $response->status
            ]);
        }

        return response()->json([
            'status' => $response->status,
            'result' => $response->result,
            'error' => 'Unable to get search results at this time'
        ]);
    }

    /**
     * @throws \JsonException
     */
    public function searchTypeGenreNoToken( FilteredSearchRequest $request): JsonResponse
    {
        $orion = new OrionService();
        $orion->type = $request->type;
        $orion->queryString = $request->queryString;
        $orion->category = $request->category;

        $response = $orion->genericSearch();

        if ($response->status === "success") {
            return response()->json([
                'html' => view('components.search-result-card', [
                    "results" => collect($response->data)
                ])->render(),
                'result' => $response->result,
                'status' => $response->status
            ]);
        }

        return response()->json([
            'status' => $response->status,
            'result' => $response->result,
            'error' => 'Unable to get search results at this time'
        ]);
    }
}
